@@ -38,6 +38,8 @@ template<typename T> inline const char *FmtString(T);
 // Not implemented to prevent accidents with irregular meaning of argument:
 // template<> inline const char *FmtString(const char *&) { return "%s"; }
 
+template<> inline const char *FmtString(short)         { return "%hd"; }
+template<> inline const char *FmtString(unsigned short){ return "%hu"; }
 template<> inline const char *FmtString(int)           { return  "%i"; }
 template<> inline const char *FmtString(long)          { return "%li"; }
 template<> inline const char *FmtString(unsigned)      { return  "%u"; }
@@ -200,6 +202,19 @@ template<> inline PGSTD::string Quote(const char *const & Obj,
 }
 
 
+/// Specialization for string constants
+/** This specialization is a little complicated, because string constants are
+ * of the type char[], not of type const char * as one might expect.  Note that
+ * the size of the array is part of the type, for which reason we need it in our
+ * template here.
+ */
+template<int LEN> inline PGSTD::string Quote(const char (&Obj)[LEN],
+    					     bool EmptyIsNull=false)	//[t18]
+{
+  return Quote(PGSTD::string(Obj), EmptyIsNull);
+}
+
+
 /// Generic version: generate SQL-quoted version of object.  If EmptyIsNull is
 /// set, an empty string will generate the null value rather than an empty 
 /// string.
